// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
import { indentLess } from '@codemirror/commands';
import { searchKeymap } from '@codemirror/search';
import { nullTranslator } from '@jupyterlab/translation';
import { CodeMirrorEditor } from './editor';
/**
 * CodeMirror editor factory.
 */
export class CodeMirrorEditorFactory {
    /**
     * Construct an IEditorFactoryService for CodeMirrorEditors.
     */
    constructor(defaults = {}, translator) {
        /**
         * Create a new editor for inline code.
         */
        this.newInlineEditor = (options) => {
            options.host.dataset.type = 'inline';
            return new CodeMirrorEditor({
                ...options,
                config: { ...this.inlineCodeMirrorConfig, ...(options.config || {}) },
                translator: this.translator
            });
        };
        /**
         * Create a new editor for a full document.
         */
        this.newDocumentEditor = (options) => {
            options.host.dataset.type = 'document';
            return new CodeMirrorEditor({
                ...options,
                config: { ...this.documentCodeMirrorConfig, ...(options.config || {}) },
                translator: this.translator
            });
        };
        this.translator = translator || nullTranslator;
        this.inlineCodeMirrorConfig = {
            ...CodeMirrorEditor.defaultConfig,
            extraKeys: [
                {
                    key: 'Tab',
                    run: CodeMirrorEditor.indentMoreOrInsertTab,
                    shift: indentLess
                },
                ...searchKeymap
            ],
            ...defaults
        };
        this.documentCodeMirrorConfig = {
            ...CodeMirrorEditor.defaultConfig,
            extraKeys: [
                {
                    key: 'Tab',
                    run: CodeMirrorEditor.indentMoreOrInsertTab,
                    shift: indentLess
                },
                {
                    key: 'Shift-Enter',
                    run: (target) => {
                        return true;
                    }
                }
            ],
            lineNumbers: true,
            scrollPastEnd: true,
            ...defaults
        };
    }
}
//# sourceMappingURL=factory.js.map